==> ejc-ztpcct-impl-3.0.0-20231214.070836-66-sources.jar: com/ejianc/ztpc/vo/OpinionInfoVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 意见栏
 * 
 * @author generator
 * 
 */
public class OpinionInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态
    private String relativeChapter; // 对应章节
    private String originalContent; // 原文内容
    private String editOpinion; // 修改意见
    private String reminderContent; // 建议项/必改项
    private Long proposeUserId; // 提出人
    private String mobile; // 手机号
    private String whetherAccept; // 是否采纳（Y：是，N：否）
    private String abarbeitungCase; // 整改情况
    private Long attachment; // 附件
    private Long pid; // 父ID
    private String proposeUserName; // 提出人名称
    private Integer reminderContentId; // 建议项/必改项(下拉)
    private  Integer certificationConclusionId;//认证结论

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getRelativeChapter() {
        return relativeChapter;
    }

    public void setRelativeChapter(String relativeChapter) {
        this.relativeChapter = relativeChapter;
    }

    public String getOriginalContent() {
        return originalContent;
    }

    public void setOriginalContent(String originalContent) {
        this.originalContent = originalContent;
    }

    public String getEditOpinion() {
        return editOpinion;
    }

    public void setEditOpinion(String editOpinion) {
        this.editOpinion = editOpinion;
    }
    public String getReminderContent() {
        return reminderContent;
    }

    public void setReminderContent(String reminderContent) {
        this.reminderContent = reminderContent;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getProposeUserId() {
        return proposeUserId;
    }

    @ReferDeserialTransfer
    public void setProposeUserId(Long proposeUserId) {
        this.proposeUserId = proposeUserId;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getWhetherAccept() {
        return whetherAccept;
    }

    public void setWhetherAccept(String whetherAccept) {
        this.whetherAccept = whetherAccept;
    }
    public String getAbarbeitungCase() {
        return abarbeitungCase;
    }

    public void setAbarbeitungCase(String abarbeitungCase) {
        this.abarbeitungCase = abarbeitungCase;
    }
    public Long getAttachment() {
        return attachment;
    }

    public void setAttachment(Long attachment) {
        this.attachment = attachment;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getProposeUserName() {
        return proposeUserName;
    }

    public void setProposeUserName(String proposeUserName) {
        this.proposeUserName = proposeUserName;
    }

    public Integer getReminderContentId() {
        return reminderContentId;
    }

    public void setReminderContentId(Integer reminderContentId) {
        this.reminderContentId = reminderContentId;
    }

    public Integer getCertificationConclusionId() {
        return certificationConclusionId;
    }

    public void setCertificationConclusionId(Integer certificationConclusionId) {
        this.certificationConclusionId = certificationConclusionId;
    }
}

==> ejc-ztpcct-impl-3.0.0-20240428.030022-123-sources.jar: com/ejianc/ztpc/vo/OpinionInfoVO.java <==
package com.ejianc.ztpc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 意见栏
 * 
 * @author generator
 * 
 */
public class OpinionInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 单据编号
    private String name; // 单据名称
    private Integer billState; // 单据状态
    private String relativeChapter; // 对应章节
    private String originalContent; // 原文内容
    private String editOpinion; // 修改意见
    private String reminderContent; // 建议项/必改项
    private Long proposeUserId; // 提出人
    private String mobile; // 手机号
    private String whetherAccept; // 是否采纳（Y：是，N：否）
    private String abarbeitungCase; // 整改情况
    private Long attachment; // 附件
    private Long pid; // 父ID
    private String proposeUserName; // 提出人名称
    private Integer reminderContentId; // 建议项/必改项(下拉)
    private  Integer certificationConclusionId;//论证结论

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getRelativeChapter() {
        return relativeChapter;
    }

    public void setRelativeChapter(String relativeChapter) {
        this.relativeChapter = relativeChapter;
    }

    public String getOriginalContent() {
        return originalContent;
    }

    public void setOriginalContent(String originalContent) {
        this.originalContent = originalContent;
    }

    public String getEditOpinion() {
        return editOpinion;
    }

    public void setEditOpinion(String editOpinion) {
        this.editOpinion = editOpinion;
    }
    public String getReminderContent() {
        return reminderContent;
    }

    public void setReminderContent(String reminderContent) {
        this.reminderContent = reminderContent;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getProposeUserId() {
        return proposeUserId;
    }

    @ReferDeserialTransfer
    public void setProposeUserId(Long proposeUserId) {
        this.proposeUserId = proposeUserId;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getWhetherAccept() {
        return whetherAccept;
    }

    public void setWhetherAccept(String whetherAccept) {
        this.whetherAccept = whetherAccept;
    }
    public String getAbarbeitungCase() {
        return abarbeitungCase;
    }

    public void setAbarbeitungCase(String abarbeitungCase) {
        this.abarbeitungCase = abarbeitungCase;
    }
    public Long getAttachment() {
        return attachment;
    }

    public void setAttachment(Long attachment) {
        this.attachment = attachment;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getProposeUserName() {
        return proposeUserName;
    }

    public void setProposeUserName(String proposeUserName) {
        this.proposeUserName = proposeUserName;
    }

    public Integer getReminderContentId() {
        return reminderContentId;
    }

    public void setReminderContentId(Integer reminderContentId) {
        this.reminderContentId = reminderContentId;
    }

    public Integer getCertificationConclusionId() {
        return certificationConclusionId;
    }

    public void setCertificationConclusionId(Integer certificationConclusionId) {
        this.certificationConclusionId = certificationConclusionId;
    }
}
